@@ -3,7 +3,7 @@
 """pandoc-eqnos: a pandoc filter that inserts equation nos. and refs."""
 
 
-__version__ = '2.2.1'
+__version__ = '2.3.0'
 
 
 # Copyright 2015-2020 Thomas J. Duck.
@@ -53,12 +53,11 @@ from pandocfilters import Math, RawInline, Str, Span
 import pandocxnos
 from pandocxnos import PandocAttributes
 from pandocxnos import STRTYPES, STDIN, STDOUT, STDERR
-from pandocxnos import check_bool, get_meta
+from pandocxnos import elt, check_bool, get_meta
 from pandocxnos import repair_refs, process_refs_factory, replace_refs_factory
 from pandocxnos import attach_attrs_factory, detach_attrs_factory
 from pandocxnos import insert_secnos_factory, delete_secnos_factory
-from pandocxnos import elt
-
+from pandocxnos import version
 
 # Patterns for matching labels and references
 LABEL_PATTERN = re.compile(r'(eq:[\w/-]*)')
@@ -72,6 +71,7 @@ numbersections = False  # Flags that equations should be numbered by section
 secoffset = 0           # Section number offset
 eqref = False           # Flags that \eqref should be used
 warninglevel = 2        # 0 - no warnings; 1 - some warnings; 2 - all warnings
+default_env = 'equation'
 
 # Processing state variables
 cursec = None    # Current section
@@ -187,8 +187,14 @@ def _add_markup(fmt, eq, value):
     if eq['is_unnumbered']:  # Unnumbered is also unreferenceable
         ret = None
     elif fmt in ['latex', 'beamer']:
+        if 'env' in attrs:
+            env = attrs['env']
+        else:
+            env = default_env
+        env, _, arg = env.partition('.')
         ret = RawInline('tex',
-                        r'\begin{equation}%s\end{equation}'%value[-1])
+                        r'\begin{%s}%s%s\end{%s}'% \
+                        (env, '{%s}'%arg if arg else '', value[-1], env))
     elif fmt in ('html', 'html4', 'html5', 'epub', 'epub2', 'epub3') and \
       LABEL_PATTERN.match(attrs.id):
         # Present equation and its number in a span
@@ -285,6 +291,7 @@ def process(meta):
     global plusname_changed  # Flags that the plus name changed
     global starname_changed  # Flags that the star name changed
     global eqref             # Flags that \eqref should be used
+    global default_env       # Default equations environment
 
     # Read in the metadata fields and do some checking
 
@@ -301,7 +308,8 @@ def process(meta):
                  'eqnos-plus-name', 'eqnos-star-name',
                  'eqnos-number-by-section', 'xnos-number-by-section',
                  'xnos-number-offset',
-                 'eqnos-eqref']
+                 'eqnos-eqref',
+                 'eqnos-default-env']
 
     if warninglevel:
         for name in meta:
@@ -367,6 +375,9 @@ def process(meta):
         if eqref:  # Eqref and cleveref are mutually exclusive
             cleveref = False
 
+    if 'eqnos-default-env' in meta:
+        default_env = get_meta(meta, 'eqnos-default-env')
+
 def add_tex(meta):
     """Adds tex to the meta data."""
 
@@ -448,7 +459,9 @@ def add_html(meta, fmt):
     # See https://github.com/jgm/pandoc/issues/3139.
 
     if targets:
-        attr = 'type="text/css"' if fmt == 'html4' else ''
+        cond = fmt == 'html4' or \
+          (fmt == 'html' and version(PANDOCVERSION) < version('2.0'))
+        attr = ' type="text/css"' if cond else ''
         pandocxnos.add_to_header_includes(meta, 'html',
                                           EQUATION_STYLE_HTML%attr)
 
@@ -481,8 +494,10 @@ def main(stdin=STDIN, stdout=STDOUT, stderr=STDERR):
     AttrMath = elt('Math', 3)
 
     # Chop up the doc
-    meta = doc['meta'] if PANDOCVERSION >= '1.18' else doc[0]['unMeta']
-    blocks = doc['blocks'] if PANDOCVERSION >= '1.18' else doc[1:]
+    meta = doc['meta'] if version(PANDOCVERSION) >= version('1.18') \
+      else doc[0]['unMeta']
+    blocks = doc['blocks'] if version(PANDOCVERSION) >= version('1.18') \
+      else doc[1:]
 
     # Process the metadata variables
     process(meta)
@@ -517,7 +532,7 @@ def main(stdin=STDIN, stdout=STDOUT, stderr=STDERR):
         add_html(meta, fmt)
 
     # Update the doc
-    if PANDOCVERSION >= '1.18':
+    if version(PANDOCVERSION) >= version('1.18'):
         doc['blocks'] = altered
     else:
         doc = doc[:1] + altered
